@@ -8,7 +8,7 @@ pub struct Sha256Algorithm {}
 impl Hasher for Sha256Algorithm {
     type Hash = [u8; 32];
 
-    fn hash(data: &Vec<u8>) -> [u8; 32] {
+    fn hash(data: &[u8]) -> [u8; 32] {
         let mut hasher = Sha256::new();
 
         hasher.update(data);
